summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/contactlist/kopetelviprops.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/contactlist/kopetelviprops.cpp')
-rw-r--r--kopete/kopete/contactlist/kopetelviprops.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kopete/kopete/contactlist/kopetelviprops.cpp b/kopete/kopete/contactlist/kopetelviprops.cpp
index f9c7cbbc..b1047dff 100644
--- a/kopete/kopete/contactlist/kopetelviprops.cpp
+++ b/kopete/kopete/contactlist/kopetelviprops.cpp
@@ -26,7 +26,7 @@
#include <tqapplication.h>
#include <tqcheckbox.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpushbutton.h>
#include <tqradiobutton.h>
#include <tqtabwidget.h>
@@ -66,7 +66,7 @@ const char MC_UNK[] = "metacontact_unknown";
KopeteGVIProps::KopeteGVIProps(KopeteGroupViewItem *gvi, TQWidget *parent, const char *name)
-: KDialogBase(parent, name, true, i18n("Properties of Group %1").arg(gvi->group()->displayName()), Ok|Cancel, Ok, false)
+: KDialogBase(parent, name, true, i18n("Properties of Group %1").tqarg(gvi->group()->displayName()), Ok|Cancel, Ok, false)
{
mainWidget = new KopeteGVIPropsWidget(this, "mainWidget");
mainWidget->icnbOpen->setIconSize(KIcon::SizeSmall);
@@ -146,7 +146,7 @@ void KopeteGVIProps::slotIconChanged()
KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, TQWidget *parent, const char *name)
-: KDialogBase(parent, name, true, i18n("Properties of Meta Contact %1").arg(lvi->metaContact()->displayName()), Ok|Cancel, Ok, false)
+: KDialogBase(parent, name, true, i18n("Properties of Meta Contact %1").tqarg(lvi->metaContact()->displayName()), Ok|Cancel, Ok, false)
{
m_countPhotoCapable = 0;
mainWidget = new KopeteMetaLVIPropsWidget( this, "mainWidget" );
@@ -157,10 +157,10 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, TQWidget *pare
mNotificationProps = new CustomNotificationProps( this, lvi->metaContact() );
// add a button to the notification props to get the sound from KABC
- // the widget's vert box layout, horiz box layout containing button, spacer, followed by a spacer
- TQBoxLayout * vb = static_cast<TQVBoxLayout*>( mNotificationProps->widget()->layout() );
+ // the widget's vert box tqlayout, horiz box tqlayout containing button, spacer, followed by a spacer
+ TQBoxLayout * vb = static_cast<TQVBoxLayout*>( mNotificationProps->widget()->tqlayout() );
- TQHBoxLayout* hb = new TQHBoxLayout( vb, -1, "soundFromKABClayout" );
+ TQHBoxLayout* hb = new TQHBoxLayout( vb, -1, "soundFromKABCtqlayout" );
mFromKABC = new TQPushButton( i18n( "Sync KABC..." ), mNotificationProps->widget(), "getSoundFromKABC" );
hb->addWidget( mFromKABC ); // [ [Button] <-xxxxx-> ]
hb->addStretch();
@@ -187,19 +187,19 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, TQWidget *pare
TQString offlineName = item->metaContact()->icon( Kopete::ContactListElement::Offline );
if(offlineName.isEmpty())
- offlineName = TQString::fromLatin1(MC_OFF); // Default
+ offlineName = TQString::tqfromLatin1(MC_OFF); // Default
TQString onlineName = item->metaContact()->icon( Kopete::ContactListElement::Online );
if(onlineName.isEmpty())
- onlineName = TQString::fromLatin1(MC_ON); // Default
+ onlineName = TQString::tqfromLatin1(MC_ON); // Default
TQString awayName = item->metaContact()->icon( Kopete::ContactListElement::Away );
if(awayName.isEmpty())
- awayName = TQString::fromLatin1(MC_AW); // Default
+ awayName = TQString::tqfromLatin1(MC_AW); // Default
TQString unknownName = item->metaContact()->icon( Kopete::ContactListElement::Unknown );
if(unknownName.isEmpty())
- unknownName = TQString::fromLatin1(MC_UNK); // Default
+ unknownName = TQString::tqfromLatin1(MC_UNK); // Default
mainWidget->icnbOffline->setIcon( offlineName );
mainWidget->icnbOnline->setIcon( onlineName );